<?php

use CodeIgniter\Router\RouteCollection;

// Enable CORS headers for all requests
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type, Authorization");

/**
 * @var RouteCollection $routes
 */
$routes->get('/', 'Home::index');

$routes->get('email-test', 'EmailTest::index');

// Registration Routes
$routes->get('register', 'Auth::register');
$routes->post('auth/processRegister', 'Auth::processRegister');

// Login Routes
$routes->get('login', 'Auth::login');
$routes->post('auth/processLogin', 'Auth::processLogin');

// Email Verification Route
$routes->get('auth/verifyEmail/(:any)', 'Auth::verifyEmail/$1');

// Forgot Password Routes
$routes->get('forgotPassword', 'Auth::forgotPassword'); // Show form
$routes->post('forgotPassword', 'Auth::processForgotPassword'); // Process form

// Reset Password Routes
$routes->get('auth/resetPassword/(:any)', 'Auth::resetPassword/$1');
$routes->post('auth/processResetPassword/(:any)', 'Auth::processResetPassword/$1');

// Reg Success Page
$routes->get('register-success', 'Auth::registerSuccess');

// User Management Routes
$routes->get('users/edit/(:num)', 'Auth::editUser/$1'); // Show edit form (admin)
$routes->post('users/update/(:num)', 'Auth::updateUser/$1'); // Process user update
$routes->get('profile/edit', 'Auth::editProfile'); // User self-edit
$routes->post('profile/update', 'Auth::updateProfile'); // Process profile update

// Dashboard
$routes->get('dashboard', 'DashboardController::index');

// Log Out
$routes->get('logout', 'Auth::logout');

// Form Builder
$routes->get('form-builder', 'FormBuilder::index');
// DEV
$routes->get('form-builder-dev', 'FormBuilder::dev');

// Test Insert Route (for troubleshooting)
// Place this BEFORE the generic app-builder route for higher priority.
$routes->get('app-builder/testInsert', 'AppBuilder::testInsert');

// App Builder Routes
$routes->get('app-builder', 'AppBuilder::index');
$routes->post('save_app', 'AppBuilder::saveApp');

// APP Routes Fix (for modules)
$routes->get('modules/(:any)', function ($moduleFile) {
    $filePath = APPPATH . 'Views/modules/' . $moduleFile;
    
    if (!file_exists($filePath)) {
        throw \CodeIgniter\Exceptions\PageNotFoundException::forPageNotFound();
    }
    
    return view('modules/' . $moduleFile);
});

// Dedicated Module Preview Route
$routes->get('module-preview/(:any)', 'ModulePreview::show/$1');

// Application Dynamic Path
$routes->get('apps/(:segment)', 'AppBuilder::loadApp/$1');


// File Upload Route
$routes->post('upload_logo', 'UploadController::uploadLogo');

